@@ -3,7 +3,7 @@ use Moose;
 use Sub::Install;
 use namespace::autoclean;
 
-our $VERSION = '0.3.0'; # VERSION
+our $VERSION = '0.3.2'; # VERSION
 # ABSTRACT: Dist::Zilla::PluginBundle for BerryGenomics Bioinformatics Department
 
 
@@ -62,7 +62,7 @@ has commit_msg => (
   isa     => 'Str',
   lazy    => 1,
   default => sub {
-    $_[0]->payload->{commit_msg} || 'Auto commited by dzil with version %v at %d';
+    $_[0]->payload->{commit_msg} || 'Auto commited by dzil with version %v at %d%n%n%c%n';
   }
 );
 
@@ -192,7 +192,7 @@ sub configure {
       }
     ],
     [ 'Git::Tag',
-      {tag_format => 'v%v', tag_message => 'Release %v'}
+      {tag_format => '%v', tag_message => 'Release %v'}
     ],
     ['Git::Push', {remotes_must_exist => 0}],
     [ 'Git::NextVersion',
@@ -230,7 +230,7 @@ Dist::Zilla::PluginBundle::BerryGenomics - Dist::Zilla::PluginBundle for BerryGe
 
 =head1 VERSION
 
-version 0.3.0
+version 0.3.2
 
 =head1 SYNOPSIS
 
